==> fred-verifier-0.4.1.tar.gz: fred-verifier-0.4.1/verifier/common.py <==
"""Common types."""
from datetime import date, datetime
from enum import Enum, unique
from typing import Any, Dict, Generic, List, Optional, Sequence, TypeVar

from fred_api.verification.common_types_pb2 import ContactData as ContactDataMessage
from pydantic import BaseModel
from pydantic.generics import GenericModel
from regal import Address, ContactId
from regal.common import BaseId

T = TypeVar("T", bound=BaseModel)


class VerificationId(BaseId):
    """Verification id."""


class Pagination(BaseModel):
    """Token pagination model."""

    next_page_token: str = ""
    items_left: Optional[int] = None


class PaginatedList(GenericModel, Generic[T]):
    """Token paginated results."""

    results: List[T]
    pagination: Optional[Pagination] = None


@unique
class VerificationStatus(str, Enum):
    """Verification status."""

    UNKNOWN = "unknown"
    CREATED = "created"
    INITIALIZED = "initialized"
    ACCESSED = "accessed"
    PENDING = "pending"
    CONSTRAINED = "constrained"
    FUTILE = "futile"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class Event(BaseModel):
    """Verification event."""

    event_datetime: Optional[datetime] = None
    type: str
    method: Optional[str] = None
    details: Dict[str, Any] = {}


class Verification(BaseModel):
    """Verification info."""

    verification_id: VerificationId
    contact_id: ContactId
    create_datetime: datetime
    close_datetime: Optional[datetime] = None
    last_access_datetime: Optional[datetime] = None
    status: VerificationStatus = VerificationStatus.UNKNOWN
    manual_check_request: bool = False

    events: Sequence[Event] = []
    next_events: Sequence[Event] = []


class ContactData(BaseModel):
    """Contact data to be verified."""

    name: Optional[str] = None
    organization: Optional[str] = None
    birthdate: Optional[date] = None
    company_registration_number: Optional[str] = None
    address: Optional[Address] = None
    emails: List[str] = []

    def to_protobuf(self) -> ContactDataMessage:
        """Convert contact data to corresponding protobuf message."""
        message = ContactDataMessage()
        if self.name is not None:
            message.name = self.name
        if self.organization is not None:
            message.organization = self.organization
        if self.birthdate is not None:
            message.birthdate = self.birthdate.isoformat()
        if self.company_registration_number is not None:
            message.company_registration_number = self.company_registration_number
        message.emails[:] = self.emails
        if self.address is not None:
            message.address.street[:] = self.address.street
            message.address.city = self.address.city
            message.address.state_or_province = self.address.state_or_province
            message.address.postal_code = self.address.postal_code
            message.address.country_code = self.address.country_code

        return message


class VerificationResult(BaseModel):
    """Contact data verification result."""

    verify_datetime: datetime
    method: str
    data: ContactData
    contact_history_id: str

    # True - contact field passed verfication
    # False - contact field failed verification
    # None - contact field was not verified
    name: Optional[bool] = None
    organization: Optional[bool] = None
    birthdate: Optional[bool] = None
    company_registration_number: Optional[bool] = None
    address: Optional[bool] = None
    emails: Optional[bool] = None

    @property
    def success(self) -> bool:
        """Return True if contact data verification didn't fail."""
        return False not in (
            self.name,
            self.organization,
            self.birthdate,
            self.company_registration_number,
            self.address,
        )


class ContactRepresentative(BaseModel):
    """Contact representative."""

    organization: str
    address: Address

==> fred-verifier-0.5.2.tar.gz: fred-verifier-0.5.2/verifier/common.py <==
"""Common types."""
from datetime import date, datetime
from enum import Enum, unique
from typing import Any, Dict, Generic, List, Optional, Sequence, TypeVar

from fred_api.verification.common_types_pb2 import ContactData as ContactDataMessage
from fred_types import BaseId, BaseModel, ContactId, GenericModel
from regal import Address

T = TypeVar("T", bound=BaseModel)


class VerificationId(BaseId):
    """Verification id."""


class Pagination(BaseModel):
    """Token pagination model."""

    next_page_token: str = ""
    items_left: Optional[int] = None


class PaginatedList(GenericModel, Generic[T]):
    """Token paginated results."""

    results: List[T]
    pagination: Optional[Pagination] = None


@unique
class VerificationStatus(str, Enum):
    """Verification status."""

    UNKNOWN = "unknown"
    CREATED = "created"
    INITIALIZED = "initialized"
    ACCESSED = "accessed"
    PENDING = "pending"
    CONSTRAINED = "constrained"
    FUTILE = "futile"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
    CANCELED = "canceled"


class Event(BaseModel):
    """Verification event."""

    event_datetime: Optional[datetime] = None
    type: str
    method: Optional[str] = None
    details: Dict[str, Any] = {}


class Verification(BaseModel):
    """Verification info."""

    verification_id: VerificationId
    contact_id: ContactId
    create_datetime: datetime
    close_datetime: Optional[datetime] = None
    last_access_datetime: Optional[datetime] = None
    status: VerificationStatus = VerificationStatus.UNKNOWN
    manual_check_request: bool = False

    events: Sequence[Event] = []
    next_events: Sequence[Event] = []


class ContactData(BaseModel):
    """Contact data to be verified."""

    name: Optional[str] = None
    organization: Optional[str] = None
    birthdate: Optional[date] = None
    company_registration_number: Optional[str] = None
    address: Optional[Address] = None
    emails: List[str] = []

    def to_protobuf(self) -> ContactDataMessage:
        """Convert contact data to corresponding protobuf message."""
        message = ContactDataMessage()
        if self.name is not None:
            message.name = self.name
        if self.organization is not None:
            message.organization = self.organization
        if self.birthdate is not None:
            message.birthdate = self.birthdate.isoformat()
        if self.company_registration_number is not None:
            message.company_registration_number = self.company_registration_number
        message.emails[:] = self.emails
        if self.address is not None:
            message.address.street[:] = self.address.street
            message.address.city = self.address.city
            message.address.state_or_province = self.address.state_or_province
            message.address.postal_code = self.address.postal_code
            message.address.country_code = self.address.country_code

        return message


class VerificationResult(BaseModel):
    """Contact data verification result."""

    verify_datetime: datetime
    method: str
    data: ContactData
    contact_history_id: str

    # True - contact field passed verfication
    # False - contact field failed verification
    # None - contact field was not verified
    name: Optional[bool] = None
    organization: Optional[bool] = None
    birthdate: Optional[bool] = None
    company_registration_number: Optional[bool] = None
    address: Optional[bool] = None
    emails: Optional[bool] = None

    @property
    def success(self) -> bool:
        """Return True if contact data verification didn't fail."""
        return False not in (
            self.name,
            self.organization,
            self.birthdate,
            self.company_registration_number,
            self.address,
        )


class ContactRepresentative(BaseModel):
    """Contact representative."""

    organization: str
    address: Address
